@@ -91,7 +91,6 @@ Modification by stdweird:
 #      An array variable from which Bash reads the possible completions
 #      generated by a shell function invoked by the programmable
 #      completion facility (*note Programmable Completion::).
-from __future__ import print_function
 
 import copy
 import glob
@@ -106,7 +105,6 @@ from optparse import OptionParser, Option
 from pprint import pformat
 
 from vsc.utils.missing import shell_quote
-from vsc.utils.py2vs3 import is_string
 
 debugfn = None  # for debugging only
 
@@ -206,7 +204,7 @@ class FileCompleter(Completer):
     CALL_ARGS_OPTIONAL = ['prefix']
 
     def __init__(self, endings=None):
-        if is_string(endings):
+        if isinstance(endings, str):
             endings = [endings]
         elif endings is None:
             endings = []
@@ -276,11 +274,11 @@ class RegexCompleter(Completer):
     def __init__(self, regexlist, always_dirs=True):
         self.always_dirs = always_dirs
 
-        if is_string(regexlist):
+        if isinstance(regexlist, str):
             regexlist = [regexlist]
         self.regexlist = []
         for regex in regexlist:
-            if is_string(regex):
+            if isinstance(regex, str):
                 regex = re.compile(regex)
             self.regexlist.append(regex)
 
@@ -538,7 +536,7 @@ def autocomplete(parser, arg_completer=None, opt_completer=None, subcmd_complete
     # File completion.
     if completer and (not prefix or not prefix.startswith('-')):
         # Call appropriate completer depending on type.
-        if isinstance(completer, (list, tuple)) or is_string(completer):
+        if isinstance(completer, (list, tuple)) or isinstance(completer, str):
             completer = FileCompleter(completer)
         elif not isinstance(completer, (types.FunctionType, types.LambdaType, types.ClassType, types.ObjectType)):
             # TODO: what to do here?
@@ -546,7 +544,7 @@ def autocomplete(parser, arg_completer=None, opt_completer=None, subcmd_complete
 
         completions = completer(**completer_kwargs)
 
-    if is_string(completions):
+    if isinstance(completions, str):
         # is a bash command, just run it
         if SHELL in (BASH,):  # TODO: zsh
             print(completions)
@@ -588,9 +586,8 @@ def autocomplete(parser, arg_completer=None, opt_completer=None, subcmd_complete
         if isinstance(debugfn, logging.Logger):
             debugfn.debug(txt)
         else:
-            f = open(debugfn, 'a')
-            f.write(txt)
-            f.close()
+            with open(debugfn, 'a') as fih:
+                fih.write(txt)
 
     # Exit with error code (we do not let the caller continue on purpose, this
     # is a run for completions only.)
